@@ -1,5 +1,6 @@
 import sys
 import itertools
+import copy
 import numpy as np
 import scipy.cluster.hierarchy as sch
 import scipy.stats
@@ -291,7 +292,7 @@ class Correlation:
                                link_color_func=lambda k: 'darkred')
         axdendro.set_xticks([])
         axdendro.set_yticks([])
-        cmap = plt.get_cmap(colormap)
+        cmap = copy.copy(plt.get_cmap(colormap))
 
         # this line simply makes a new cmap, based on the original
         # colormap that goes from 0.0 to 0.9
@@ -421,7 +422,7 @@ class Correlation:
         data[-1]['colorbar'].update(title="log10(instances per bin)", titleside="right")
         data[-1].update(showscale=True)
 
-        fig['data'] = data
+        fig.add_traces(data)
         fig['layout'].update(title=plot_title, showlegend=False, annotations=annos)
 
         offline.plot(fig, filename=plot_filename, auto_open=False)
@@ -588,7 +589,7 @@ class Correlation:
         annos.append({'yanchor': 'bottom', 'xref': 'paper', 'xanchor': 'center', 'yref': 'paper', 'text': 'PCA', 'y': 1.0, 'x': 0.25, 'font': {'size': 16}, 'showarrow': False})
         annos.append({'yanchor': 'bottom', 'xref': 'paper', 'xanchor': 'center', 'yref': 'paper', 'text': 'Scree plot', 'y': 1.0, 'x': 0.75, 'font': {'size': 16}, 'showarrow': False})
 
-        fig['data'] = data
+        fig.add_traces(data)
         fig['layout']['annotations'] = annos
         offline.plot(fig, filename=plotFile, auto_open=False)
 
